Name:      libgeotiff
Version:   1.3.0
Release:   1
Summary:   GeoTIFF format library
Group:     System Environment/Libraries
License:   MIT
URL:       http://www.remotesensing.org/geotiff/geotiff.html
Source0:   ftp://ftp.remotesensing.org/pub/geotiff/%{name}/%{name}-%{version}.tar.gz
Patch0:    %{name}-%{version}-aix.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: libtiff-devel libjpeg-devel proj-devel zlib-devel
Requires: libtiff libjpeg proj zlib

%description
GeoTIFF represents an effort by over 160 different remote sensing, 
GIS, cartographic, and surveying related companies and organizations 
to establish a TIFF based interchange format for georeferenced 
raster imagery.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development Libraries for the GeoTIFF file format library
Group: Development/Libraries
Requires: pkg-config libtiff-devel
Requires: %{name} = %{version}-%{release}

%description devel
The GeoTIFF library provides support for development of geotiff image format.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%prep
%setup -q
%patch0


%build
# setup environment for 32-bit and 64-bit builds
export AR="/usr/bin/ar -X32_64"
export NM="/usr/bin/nm -X32_64"
export RANLIB="/usr/bin/ranlib -X32_64"

# first build the 64-bit version
export CC="xlc -q64"
./configure \
    --disable-shared --enable-static \
    --prefix=%{_prefix} \
    --with-proj \
    --with-tiff \
    --with-jpeg \
    --with-zip
make %{?_smp_mflags}

CreateExportList -X64 %{name}.exp .libs/%{name}.a
${CC} -qmkshrobj .libs/%{name}.a -o shr64.so -bE:%{name}.exp -ltiff -lproj
rm -f %{name}.exp

make clean

# now build the 32-bit version
export CC="xlc"
./configure \
    --disable-shared --enable-static \
    --prefix=%{_prefix} \
    --with-proj \
    --with-tiff \
    --with-jpeg \
    --with-zip
make %{?_smp_mflags}

CreateExportList %{name}.exp .libs/%{name}.a
${CC} -qmkshrobj .libs/%{name}.a -o shr.o -bE:%{name}.exp -ltiff -lproj
rm -f %{name}.exp .libs/%{name}.a
mv shr64.so shr64.o

# create the shared library to stay compatible with previous versions
${AR} -rv .libs/%{name}.a ./shr.o
${AR} -q  .libs/%{name}.a ./shr64.o

# finish the build now...
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/*

# install manually some file
cp bin/makegeo ${RPM_BUILD_ROOT}%{_bindir}
chmod 0755 ${RPM_BUILD_ROOT}%{_bindir}/makegeo

# install pkgconfig file
cat > %{name}.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}
Description: GeoTIFF file format library
Version: %{version}
Libs: -L\${libdir} -lgeotiff
Cflags: -I\${includedir}
EOF

mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/
cp %{name}.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/%{name}.pc

echo  >> ${RPM_BUILD_ROOT}%{_datadir}/epsg_csv/codes.csv

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files 
%defattr(-,root,system,-)
%doc ChangeLog LICENSE README
%{_bindir}/*
%{_libdir}/*.a
%dir %{_datadir}/epsg_csv
%attr(0644,root,system) %{_datadir}/epsg_csv/*.csv
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%attr(0644,root,system) %{_includedir}/*
%{_libdir}/pkgconfig/%{name}.pc
/usr/include/*


%changelog
* Mon May 10 2010 Michael Perzl <michael@perzl.org> - 1.3.0-1
- updated to version 1.3.0-1

* Mon May 10 2010 Michael Perzl <michael@perzl.org> - 1.2.5-1
- updated to version 1.2.5-1

* Thu May 15 2008 Michael Perzl <michael@perzl.org> - 1.2.4-1
- first version for AIX V5.1 and higher
